==> qtjambi-designer-debuginfo-macos-5.15.17.jar: sources/QtJambiDesigner/QFormBuilder_shell.h <==
#ifndef QFORMBUILDER_SHELL_H
#define QFORMBUILDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/formbuilder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtGui/qicon.h>
#include <QtGui/qpixmap.h>
#include <QtUiPlugin/customwidget.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QFormBuilder_shell : public QFormBuilder, public QtJambiShellInterface
{
public:
    QFormBuilder_shell();
    ~QFormBuilder_shell() override;

    void addMenuAction(QAction* action0) override;
    bool checkProperty(QObject* obj0, const QString& prop1) const override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& layoutName0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& widgetName0, QWidget* parentWidget1, const QString& name2) override;
    QWidget* load(QIODevice* dev0, QWidget* parentWidget1) override;
    void save(QIODevice* dev0, QWidget* widget1) override;
    void updateCustomWidgets() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFormBuilder_access : public QFormBuilder
{
    static jobject __qt_widgetByName_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID topLevel0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring layoutName0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring widgetName0, QtJambiNativeID parentWidget1, jstring name2);
    void __qt_updateCustomWidgets(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QFORMBUILDER_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.5.3.jar: sources/QtJambiDesigner/QFormBuilder_shell.h <==
#ifndef QFORMBUILDER_SHELL_H
#define QFORMBUILDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/formbuilder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#if QT_CONFIG(action)
#include <QtGui/qactiongroup.h>
#endif //QT_CONFIG(action)
#include <QtUiPlugin/customwidget.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QFormBuilder_shell : public QFormBuilder, public QtJambiShellInterface
{
public:
    QFormBuilder_shell();
    ~QFormBuilder_shell() override;

    void addMenuAction(QAction* action0) override;
    bool checkProperty(QObject* obj0, const QString& prop1) const override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& layoutName0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& widgetName0, QWidget* parentWidget1, const QString& name2) override;
    QWidget* load(QIODevice* dev0, QWidget* parentWidget1) override;
    void save(QIODevice* dev0, QWidget* widget1) override;
    void updateCustomWidgets() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFormBuilder_access : public QFormBuilder
{
    static jobject __qt_widgetByName_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID topLevel0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring layoutName0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring widgetName0, QtJambiNativeID parentWidget1, jstring name2);
    void __qt_updateCustomWidgets(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QFORMBUILDER_SHELL_H
